package
  My::Dist;

use strict;
use warnings;

# ABSTRACT: This is my Dist
# VERSION

1;
